@@ -39,6 +39,7 @@
 #include <KColorSchemeManager>
 #include <KConfig>
 #include <KConfigGroup>
+#include <KCrash>
 #include <KFileItem>
 #include <KFileMetaData/Properties>
 #include <KLocalizedString>
@@ -54,7 +55,11 @@ Application *Application::instance()
 Application::Application()
     : m_app(qApp)
     , m_config(KSharedConfig::openConfig(Global::instance()->appConfigFilePath()))
+#if KCOLORSCHEME_VERSION < QT_VERSION_CHECK(6, 6, 0)
     , m_schemes(new KColorSchemeManager(this))
+#else
+    , m_schemes(KColorSchemeManager::instance())
+#endif
     , m_systemDefaultStyle(m_app->style()->objectName())
     , m_appEventFilter{std::make_unique<ApplicationEventFilter>()}
 {
@@ -73,6 +78,8 @@ Application::Application()
     setupCommandLineParser();
     setupQmlSettingsTypes();
 
+    KCrash::initialize();
+
     connect(Global::instance(), &Global::error, this, &Application::error);
     connect(this, &Application::saveWindowGeometryAsync, Worker::instance(), &Worker::saveWindowGeometry, Qt::QueuedConnection);
 }
