@@ -8,14 +8,17 @@
 #define CUSTOMCOMMANDSMODEL_H
 
 #include <KSharedConfig>
+
 #include <QAbstractListModel>
 #include <QSortFilterProxyModel>
+#include <QtQml/qqmlregistration.h>
 
 class ActionsModel;
 
 class CustomCommandsModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(CustomCommandsModel)
 
     Q_PROPERTY(ActionsModel *appActionsModel READ appActionsModel WRITE setAppActionsModel NOTIFY appActionsModelChanged)
 
@@ -48,7 +51,7 @@ public:
     QHash<int, QByteArray> roleNames() const override;
 
     Q_INVOKABLE void init();
-    Q_INVOKABLE void moveRows(int oldIndex, int newIndex);
+    Q_INVOKABLE bool moveRows(const QModelIndex &sourceParent, int sourceRow, int count, const QModelIndex &destinationParent, int destinationChild) override;
     Q_INVOKABLE void saveCustomCommand(const QString &command, const QString &osdMessage, const QString &type);
     Q_INVOKABLE void editCustomCommand(int row, const QString &command, const QString &osdMessage, const QString &type);
     Q_INVOKABLE void toggleCustomCommand(const QString &groupName, int row, bool setOnStartup);
@@ -62,7 +65,7 @@ Q_SIGNALS:
 
 private:
     KSharedConfig::Ptr m_customCommandsConfig;
-    QList<Command *> m_customCommands;
+    QList<Command> m_customCommands;
     ActionsModel *m_appActionsModel{nullptr};
 };
 
